# Reads a set of GeoJSON files in a folder and writes selected attributes to a CSV
# Creates one CSV per JSON file
# Then zips the CSVs and deletes everything but the zipped folder

import json
import os
import zipfile
import string
import sys

workingDir = sys.argv[1]

# Set up zip file info
zFileName = os.path.join(workingDir, 'phillyfreshfood.zip')
zOut = zipfile.ZipFile(zFileName, 'w')

# Loop through each GeoJSON file
for inFile in os.listdir(workingDir):
    if inFile.endswith('.geojson'):
        inFilePath = os.path.join(workingDir, inFile)
        outFilePath = os.path.join(workingDir, inFile).replace('.geojson', '.csv')
        outFile = open(outFilePath, 'w')


        with open(inFilePath, 'r') as f:
            # Write header
            headerLine = 'name,address,hours,website,phone\n'
            outFile.write(headerLine)
            
            data = json.load(f)

            # Read each feature
            for item in data['features']:
                name = ''
                addrNum = ''
                addrStr = ''
                hours = ''
                website = ''
                phone = ''
                addrFull = ''
                addRecord = False

                # Read the feature name
                try:
                    if item['properties']['name'] is not None:
                        name = item['properties']['name']
                        addRecord = True
                    else:
                        name = 'Unnamed feature'
                except:
                    pass

                # Read the other tags, if they exist
                try:
                    otherTags = item['properties']['other_tags']      
                    otherTags = otherTags.replace('","','"~*~"')
                    otherTags = otherTags.split('~*~')
                    for otherTag in otherTags:
                        tag = otherTag.split('=>')
                        # Remove quotes around key and value
                        key = tag[0].replace('"','')
                        value = tag[1].replace('"','')
                        # Remove piece of JSON escape sequence for quotes
                        value = value.replace('\\','"')
                        # Escape double quotes that could throw off CSV
                        value = value.replace('"','""')
                        # Escape items with commas that could throw off CSV
                        if ',' in value:
                            value = '"' + value + '"'

                        # Look for desired tag values
                        if key == 'addr:housenumber':
                            addrNum = value
                            addRecord = True
                        elif key == 'addr:street':
                            addrStr = value
                            addRecord = True
                        elif key == 'opening_hours':
                            hours = value
                            addRecord = True
                        elif key == 'website':
                            website = value
                            addRecord = True
                        elif key == 'phone' or key == 'contact:phone':
                            phone = value
                            addRecord = True
                        elif key == 'addr:full':
                            addrFull = value
                            addRecord = True

                except:
                    pass

                # Determine if address information exists in the file
                addrSpacer = ''
                if addrNum != '' and addrStr != '':
                    addrSpacer = ' '
                elif addrNum == '' and addrStr == '' and addrFull != '':  #Handle case where full address exists
                    addrSpacer = addrFull
                else:
                    pass

                # If enough information exists, write the line to the file
                if addRecord == True:
                    # Create the full line
                    infoLine = name + ',' + addrNum + addrSpacer + addrStr + ',' + hours + ',' + website + ',' + phone + '\n'
                    outFile.write(infoLine.encode('utf-8'))

        outFile.close()
        zOut.write(outFilePath, os.path.basename(outFilePath))

zOut.close()

# Delete leftover CSVs not zipped
for file in os.listdir(workingDir):
    if file.endswith('.csv'):
        os.remove(os.path.join(workingDir,file))

        
